OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Невозможно выполнить запись в каталог «config».",
    "This can usually be fixed by giving the web server write access to the config directory." : "Обычно эту ошибку можно исправить, предоставив веб-серверу права на запись в каталог конфигурации.",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Если для файла «config.php» должен быть установлен режим «только чтение», задайте параметру «config_is_read_only» значение «true».",
    "See %s" : "Обратитесь к %s.",
    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "Приложение %1$s отсутствует или его версия несовместима с этим сервером. Пожалуйста, проверьте каталог приложений.",
    "Sample configuration detected" : "Обнаружена конфигурация из примера.",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Была обнаружена конфигурация из примера. Такая конфигурация не поддерживается и может повредить вашей системе. Прочтите документацию перед внесением изменений в файл config.php",
    "The page could not be found on the server." : "Страница не найдена на сервере.",
    "%s email verification" : "Проверка почтового адреса %s",
    "Email verification" : "Подтверждение адреса электронной почты",
    "Click the following button to confirm your email." : "Нажмите на кнопку чтобы подтвердить свой адрес электронной почты.",
    "Click the following link to confirm your email." : "Перейдите по ссылке чтобы подтвердить свой адрес электронной почты.",
    "Confirm your email" : "Подтвердить адрес электронной почты",
    "Other activities" : "Другие события",
    "%1$s and %2$s" : "%1$s и %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s и %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s и %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s и %5$s",
    "Education bundle" : "Образовательный пакет",
    "Enterprise bundle" : "Набор приложений для предприятий",
    "Groupware bundle" : "Набор приложений для совместной работы",
    "Hub bundle" : "Основной набор приложений",
    "Public sector bundle" : "Пакет услуг для государственного сектора",
    "Social sharing bundle" : "Набор приложений для публикации с использованием соц. сетей",
    "PHP %s or higher is required." : "Требуется PHP версии %s или выше.",
    "PHP with a version lower than %s is required." : "Требуется PHP версии ниже %s.",
    "%sbit or higher PHP required." : "Требуется PHP с разрядностью %s бит или более.",
    "The following architectures are supported: %s" : "Поддерживаются следующие архитектуры: %s",
    "The following databases are supported: %s" : "Поддерживаются следующие базы данных: %s",
    "The command line tool %s could not be found" : "Утилита командной строки %s не найдена",
    "The library %s is not available." : "Библиотека «%s» недоступна.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Требуется библиотека «%1$s» версии не меньше %2$s, установлена версия %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Требуется библиотека «%1$s» версии не выше %2$s, установлена версия %3$s.",
    "The following platforms are supported: %s" : "Поддерживаются следующие платформы: %s",
    "Server version %s or higher is required." : "Требуется сервер версии %s или выше.",
    "Server version %s or lower is required." : "Требуется сервер версии %s или ниже.",
    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Для доступа к этой настройке зарегистрированная учетная запись должна быть администратором, субадминистратором или иметь специальные права",
    "Your current IP address doesn't allow you to perform admin actions" : "Ваш текущий IP-адрес не позволяет вам выполнять действия администратора.",
    "Logged in account must be an admin or sub admin" : "Зарегистрированная учетная запись должна быть администратором или субадминистратором",
    "Logged in account must be an admin" : "Вошедший в систему пользователь должен быть администратором",
    "Wiping of device %s has started" : "Удаление данных с устройства «%s».",
    "Wiping of device »%s« has started" : "Удаление данных с устройства «%s».",
    "»%s« started remote wipe" : "Начало удаления данных с устройства «%s»",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "На устройстве или в приложении «%s» был начат процесс удаления данных. После его завершения будет отправлено ещё одно электронное письмо.",
    "Wiping of device %s has finished" : "Удаление данных с устройства  «%s» завершено.",
    "Wiping of device »%s« has finished" : "Удаление данных с устройства «%s» завершено.",
    "»%s« finished remote wipe" : "Удаление данных с устройства «%s» завершено",
    "Device or application »%s« has finished the remote wipe process." : "Процесс удаления данных на устройстве или в приложении «%s» завершён.",
    "Remote wipe started" : "Запущен процесс удаления данных с устройства",
    "A remote wipe was started on device %s" : "Запущен процесс удаления данных с устройства «%s»",
    "Remote wipe finished" : "Процесс удаления данных с устройства завершён",
    "The remote wipe on %s has finished" : "Процесс удаления данных с устройства «%s» завершён",
    "Authentication" : "Аутентификация",
    "Unknown filetype" : "Неизвестный тип файла",
    "Invalid image" : "Изображение повреждено",
    "Avatar image is not square" : "Изображение аватара не квадратное",
    "Files" : "Файлы",
    "View profile" : "Открыть профиль",
    "same time" : "в то же время",
    "_%nh_::_%nh_" : ["%nч","%nч","%nч","%nч"],
    "_%nm_::_%nm_" : ["%nм","%nм","%n м","%n м"],
    "%s ahead" : "%s вперёд",
    "%s behind" : "%s позади",
    "Local time: %s" : "Местное время: %s",
    "today" : "сегодня",
    "tomorrow" : "завтра",
    "yesterday" : "вчера",
    "_in %n day_::_in %n days_" : ["через %n день","через %n дня","через %n дней","через %n дня"],
    "_%n day ago_::_%n days ago_" : ["%n день назад","%n дня назад","%n дней назад","%n дня назад"],
    "next month" : "в следующем месяце",
    "last month" : "в прошлом месяце",
    "_in %n month_::_in %n months_" : ["через %n месяц","через %n месяца","через %n месяцев","через %n месяца"],
    "_%n month ago_::_%n months ago_" : ["%n месяц назад","%n месяца назад","%n месяцев назад","%n месяца назад"],
    "next year" : "в следующем году",
    "last year" : "в прошлом году",
    "_in %n year_::_in %n years_" : ["через %n год","через %n года","через %n лет","через %n года"],
    "_%n year ago_::_%n years ago_" : ["%n год назад","%n года назад","%n лет назад","%n года назад"],
    "_in %n hour_::_in %n hours_" : ["через %n час","через %n часа","через %n часов","через %n часа"],
    "_%n hour ago_::_%n hours ago_" : ["%n час назад","%n часа назад","%n часов назад","%n часа назад"],
    "_in %n minute_::_in %n minutes_" : ["через %n минуту","через %n минуты","через %n минут","через %n минуты"],
    "_%n minute ago_::_%n minutes ago_" : ["%n минуту назад","%n минуты назад","%n минут назад","%n минуты назад"],
    "in a few seconds" : "через несколько секунд",
    "seconds ago" : "несколько секунд назад",
    "Empty file" : "Пустой файл",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Модуль с ID «%s» не существует. Включите его в настройках приложений или обратитесь к администратору.",
    "No file conversion providers available" : "Нет доступных поставщиков услуг конвертации файлов",
    "File is too large to convert" : "Файл слишком большой для преобразования",
    "Destination does not match conversion extension" : "Назначение не соответствует расширению преобразования",
    "Could not convert file" : "Не удалось преобразовать файл",
    "Destination does not exist" : "Пункт назначения не существует",
    "Destination is not creatable" : "Место назначения не может быть создано",
    "Dot files are not allowed" : "Файлы начинающиеся с точки не допускаются",
    "%1$s (renamed)" : "%1$s (переименовано)",
    "renamed file" : "переименованный файл",
    "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" это запрещенное имя файла или папки.",
    "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\" является запрещенным префиксом для имен файлов или папок.",
    "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\" не допускается указывать имя файла или папки внутри него.",
    "\"%1$s\" is a forbidden file type." : "\"%1$s\" это запрещенный тип файла.",
    "Filenames must not end with \"%1$s\"." : "Имена файлов не должны заканчиваться на \"%1$s\".",
    "Invalid parent path" : "Недопустимый родительский путь",
    "File already exists" : "Файл уже существует",
    "Invalid path" : "Некорректный путь",
    "Failed to create file from template" : "Не удалось создать файл на основе шаблона",
    "Templates" : "Шаблоны",
    "Storage %s cannot be moved" : "Хранилище %s не может быть перемещено",
    "Moving a share (%s) into a shared folder is not allowed" : "Перемещение общего ресурса (%s) в общую папку запрещено",
    "Moving a storage (%s) into a shared folder is not allowed" : "Перемещение хранилища (%s) в общую папку запрещено",
    "Moving a share (%s) into another share (%s) is not allowed" : "Перемещение общего ресурса (%s) в другой общий ресурс (%s) запрещено",
    "Moving a share (%s) into another storage (%s) is not allowed" : "Перемещение общего ресурса (%s) в другое хранилище (%s) запрещено",
    "Moving a storage (%s) into a share (%s) is not allowed" : "Перемещение хранилища (%s) в общий ресурс (%s) запрещено",
    "Moving a storage (%s) into another storage (%s) is not allowed" : "Перемещение хранилища (%s) в другое хранилище (%s) запрещено",
    "Path contains invalid segments" : "Путь содержит недопустимые сегменты",
    "Filename is a reserved word" : "Имя файла - это зарезервированное слово",
    "Filename contains at least one invalid character" : "Имя файла содержит как минимум один недопустимый символ",
    "Filename is too long" : "Имя файла слишком длинное",
    "Empty filename is not allowed" : "Пустое имя файла не допускается",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Приложение «%s» не может быть установлено, так как файл с информацией о приложении не может быть прочтен.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Приложение «%s» не может быть установлено, потому что оно несовместимо с этой версией сервера",
    "__language_name__" : "Русский",
    "This is an automatically sent email, please do not reply." : "Это сообщение отправлено автоматически и не требует ответа.",
    "Help & privacy" : "Помощь и конфиденциальность",
    "Appearance and accessibility" : "Внешний вид и доступность",
    "Apps" : "Приложения",
    "Personal settings" : "Личные настройки",
    "Administration settings" : "Параметры сервера",
    "Settings" : "Настройки",
    "Log out" : "Выйти",
    "Accounts" : "Учётные записи",
    "Bluesky" : "Bluesky",
    "View %s on Bluesky" : "Просмотреть %s на Bluesky",
    "Email" : "Адрес эл. почты",
    "Mail %s" : "Написать %s",
    "Fediverse" : "Федиверс",
    "View %s on the fediverse" : "Открыть %s в Федиверс",
    "Phone" : "Телефон",
    "Call %s" : "Позвонить %s",
    "Twitter" : "Твиттер",
    "View %s on Twitter" : "Посмотреть профиль %s в Твиттере",
    "Website" : "Сайт",
    "Visit %s" : "Посетить сайт %s",
    "Address" : "Адрес",
    "Profile picture" : "Изображение профиля",
    "About" : "О себе",
    "Display name" : "Отображаемое имя",
    "Headline" : "Заголовок",
    "Organization" : "Организация",
    "Role" : "Роль",
    "Pronouns" : "Местоимения",
    "Unknown account" : "Неизвестный аккаунт",
    "Additional settings" : "Дополнительные настройки",
    "Enter the database Login and name for %s" : "Введите логин и имя пользователя базы данных для %s",
    "Enter the database Login for %s" : "Введите логин в базе данных для %s",
    "Enter the database name for %s" : "Укажите название базы данных %s",
    "You cannot use dots in the database name %s" : "Имя базы данных %s не может содержать символ точки",
    "MySQL Login and/or password not valid" : "Неверный логин и/или пароль для входа в MySQL",
    "You need to enter details of an existing account." : "Необходимо уточнить данные существующего акаунта.",
    "Oracle connection could not be established" : "Соединение с Oracle не может быть установлено",
    "Oracle Login and/or password not valid" : "Неверный логин и/или пароль Oracle",
    "PostgreSQL Login and/or password not valid" : "Неверный логин и/или пароль для PostgreSQL",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X не поддерживается, и %s может работать некорректно на этой платформе. Используйте на свой страх и риск!",
    "For the best results, please consider using a GNU/Linux server instead." : "Для достижения наилучших результатов, рассмотрите вариант использования сервера на GNU/Linux.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Кажется что экземпляр этого %s работает в 32-битной среде PHP и в php.ini был настроен open_basedir. Это приведёт к проблемам с файлами более 4 ГБ и настоятельно не рекомендуется.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Удалите директиву open_basedir из файла php.ini или смените PHP на 64-разрядную сборку.",
    "Set an admin Login." : "Установите логин администратора.",
    "Set an admin password." : "Задать пароль для admin.",
    "Cannot create or write into the data directory %s" : "Не удалось создать или записать в каталог данных «%s»",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Бэкенд общего доступа %s должен реализовывать интерфейс OCP\\Share_Backend",
    "Sharing backend %s not found" : "Механизм предоставления общего доступа %s не найден",
    "Sharing backend for %s not found" : "Не найден механизм предоставления общего доступа для %s ",
    "%1$s shared %2$s with you" : "%1$s поделился(ась) %2$s с вами",
    "Open %s" : "Открыть %s",
    "%1$s via %2$s" : "%1$s через %2$s",
    "%1$s shared %2$s with you and wants to add:" : "%1$s поделился(ась) %2$s с вами и хочет добавить:",
    "%1$s shared %2$s with you and wants to add" : "%1$s поделился(ась) %2$s с вами и хочет добавить",
    "%s added a note to a file shared with you" : "%s добавил(а) заметку к файлу, которым поделился(ась) с вами",
    "Passwords are enforced for link and mail shares" : "Для общих ссылок и почтовых рассылок применяются пароли",
    "Share recipient is not a valid user" : "Получатель общего ресурса — некорректный пользователь",
    "Share recipient is not a valid group" : "Получатель общего ресурса — некорректная группа",
    "Share recipient should be empty" : "Получатель общего ресурса должен быть пустым",
    "Share recipient should not be empty" : "Получатель общего ресурса не должен быть пустым",
    "Share recipient is not a valid circle" : "Получатель общего ресурса — некорректный круг",
    "Unknown share type" : "Общий доступ неизвестного типа",
    "Share initiator must be set" : "Должен быть задан инициатор общего ресурса",
    "Cannot share with yourself" : "Не могу поделиться с самим собой",
    "Shared path must be set" : "Должен быть указан путь к общему ресурсу",
    "Shared path must be either a file or a folder" : "Путь должен указывать на файл или папку",
    "You cannot share your root folder" : "Вы не можете предоставить общий доступ к своей корневой папке",
    "You are not allowed to share %s" : "Вам не разрешено делиться %s",
    "Valid permissions are required for sharing" : "Для общего ресурса необходимы корректные права",
    "File shares cannot have create or delete permissions" : "Для файловых общих ресурсов нельзя задавать права доступа на создание или удаление",
    "Cannot increase permissions of %s" : "Не удалось повысить права доступа %s",
    "Shares need at least read permissions" : "Общим ресурсам требуются как минимум разрешения на чтение",
    "Files cannot be shared with delete permissions" : "Права на удаление файлов не позволяют открывать общий доступ к ним",
    "Files cannot be shared with create permissions" : "Права на создание файлов не позволяют открывать общий доступ к ним",
    "Expiration date is in the past" : "Дата окончания срока действия уже прошла",
    "Expiration date is enforced" : "Срок годности истекает",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Срок окончания не может быть более %n дня","Срок окончания не может быть более %n дней","Срок окончания не может быть более %n дней","Срок окончания не может быть более %n дней"],
    "Sharing is only allowed with group members" : "Разрешено публиковать только для участников группы",
    "Sharing %s failed, because this item is already shared with the account %s" : "Не удалось поделиться %s, так как этот элемент уже используется для доступа к учетной записи %s",
    "Group sharing is now allowed" : "Теперь разрешен общий доступ к группам",
    "Sharing is only allowed within your own groups" : "Общий доступ разрешен только в ваших собственных группах",
    "Path is already shared with this group" : "Путь уже является общим для этой группы",
    "Link sharing is not allowed" : "Обмен ссылками запрещен",
    "Public upload is not allowed" : "Публичная загрузка данных запрещена",
    "You cannot share a folder that contains other shares" : "Нельзя делиться папкой, содержащей другие общие ресурсы",
    "Sharing is disabled" : "Общий доступ отключен",
    "Sharing is disabled for you" : "Общий доступ для вас отключен",
    "Cannot share with the share owner" : "Невозможно поделиться с владельцем общего доступа",
    "Share does not have a full ID" : "Общий ресурс не имеет полного идентификатора",
    "Cannot change share type" : "Невозможно изменить тип общего ресурса",
    "Can only update recipient on user shares" : "Может обновлять информацию о получателе только в общих папках пользователей",
    "Cannot enable sending the password by Talk with an empty password" : "Не удается включить отправку пароля по телефону с пустым паролем",
    "Cannot enable sending the password by Talk without setting a new password" : "Невозможно включить отправку пароля по телефону без установки нового пароля",
    "Cannot disable sending the password by Talk without setting a new password" : "Невозможно отключить отправку пароля по телефону без установки нового пароля",
    "Share provider does not support accepting" : "Поставщик общего доступа не поддерживает прием",
    "Cannot change target of link share" : "Невозможно изменить цель публикации ссылки",
    "Invalid share recipient" : "Некорректный получатель общего ресурса",
    "Group \"%s\" does not exist" : "Группа \"%s\" не существует",
    "The requested share does not exist anymore" : "Запрошенный общий ресурс более не существует.",
    "The requested share comes from a disabled user" : "Запрос на общий доступ поступает от отключенного пользователя",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Пользователь не был создан, достигнуто ограничение количества пользователей. Для получения дополнительных сведений проверьте уведомления.",
    "Could not find category \"%s\"" : "Категория «%s»  не найдена",
    "Input text" : "Введите текст",
    "The input text" : "Вводимый текст",
    "Sunday" : "Воскресенье",
    "Monday" : "Понедельник",
    "Tuesday" : "Вторник",
    "Wednesday" : "Среда",
    "Thursday" : "Четверг",
    "Friday" : "Пятница",
    "Saturday" : "Суббота",
    "Sun." : "Вс.",
    "Mon." : "Пн.",
    "Tue." : "Вт.",
    "Wed." : "Ср.",
    "Thu." : "Чт.",
    "Fri." : "Пт.",
    "Sat." : "Сб.",
    "Su" : "Вс",
    "Mo" : "Пн",
    "Tu" : "Вт",
    "We" : "Ср",
    "Th" : "Чт",
    "Fr" : "Пт",
    "Sa" : "Сб",
    "January" : "Январь",
    "February" : "Февраль",
    "March" : "Март",
    "April" : "Апрель",
    "May" : "Май",
    "June" : "Июнь",
    "July" : "Июль",
    "August" : "Август",
    "September" : "Сентябрь",
    "October" : "Октябрь",
    "November" : "Ноябрь",
    "December" : "Декабрь",
    "Jan." : "Янв.",
    "Feb." : "Фев.",
    "Mar." : "Мар.",
    "Apr." : "Апр.",
    "May." : "Май",
    "Jun." : "Июн.",
    "Jul." : "Июл.",
    "Aug." : "Авг.",
    "Sep." : "Сен.",
    "Oct." : "Окт.",
    "Nov." : "Нояб.",
    "Dec." : "Дек.",
    "A valid password must be provided" : "Укажите допустимый пароль",
    "The Login is already being used" : "Логин уже используется",
    "Could not create account" : "Не удалось создать учетную запись",
    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "В логине разрешены только следующие символы: \"a-z\", \"A-Z\", \"0-9\", пробелы и \"_.@-'\"",
    "A valid Login must be provided" : "Необходимо указать действительный логин для входа в систему",
    "Login contains whitespace at the beginning or at the end" : "Имя пользователя содержит пробелы в начале или в конце",
    "Login must not consist of dots only" : "Логин не должен состоять только из точек",
    "Username is too long" : "Имя пользователя слишком длинное",
    "Login is invalid because files already exist for this user" : "Логин недействителен, поскольку файлы для этого пользователя уже существуют",
    "Account disabled" : "Учетная запись отключена",
    "Login canceled by app" : "Вход отменен приложением",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Приложение «%1$s» не может быть установлено, так как не удовлетворены следующие зависимости: %2$s",
    "a safe home for all your data" : "надёжный дом для всех ваших данных",
    "Application is not enabled" : "Приложение не разрешено",
    "Authentication error" : "Ошибка аутентификации",
    "Token expired. Please reload page." : "Токен просрочен. Перезагрузите страницу.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Не установлены драйвера баз данных (sqlite, mysql или postgresql)",
    "Cannot write into \"config\" directory." : "Невозможно выполнить запись в каталог «config».",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Обычно это можно исправить, предоставив веб-серверу права на запись в каталог конфигурации. Обратитесь к %s.",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Если для файла «config.php» должен быть установлен режим «только чтение», задайте параметру \"config_is_read_only\" значение \"true\". Изучите %s.",
    "Cannot create \"data\" directory." : "Невозможно создать каталог «data».",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Обычно это можно исправить, предоставив веб-серверу права на запись в корневой каталог. Обратитесь к %s",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Разрешения обычно можно исправить, предоставив веб-серверу право на запись в корневой каталог. Обратитесь к %s.",
    "Your data directory is not writable." : "Каталог данных недоступен для записи.",
    "Setting locale to %s failed." : "Не удалось настроить локаль %s.",
    "Please install one of these locales on your system and restart your web server." : "Установите один из этих языковых пакетов и перезапустите веб-сервер.",
    "PHP module %s not installed." : "Не установлен PHP-модуль %s.",
    "Please ask your server administrator to install the module." : "Попросите администратора сервера установить этот модуль.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Параметру PHP «%s» не присвоено значение «%s».",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Настройка этого параметра в файле php.ini восстановит работоспособность Nextcloud",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Очевидно, PHP настроен на вычищение блоков встроенной документации. Это сделает несколько центральных приложений недоступными.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Возможно это вызвано кэшем/ускорителем вроде Zend OPcache или eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Модули PHP были установлены, но они все еще перечислены как недостающие?",
    "Please ask your server administrator to restart the web server." : "Пожалуйста, попросите вашего администратора перезапустить веб-сервер.",
    "The required %s config variable is not configured in the config.php file." : "Необходимая переменная %s не настроена в файле config.php.",
    "Please ask your server administrator to check the Nextcloud configuration." : "Пожалуйста, попросите администратора вашего сервера проверить конфигурацию Nextcloud.",
    "Your data directory is readable by other people." : "Ваш каталог данных доступен для чтения другими пользователями.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Пожалуйста, измените разрешения на 0770, чтобы другие пользователи не могли просматривать этот каталог.",
    "Your data directory must be an absolute path." : "Каталог данных должен быть указан в виде абсолютного пути.",
    "Check the value of \"datadirectory\" in your configuration." : "Проверьте в значение параметра «datadirectory» в файле конфигурации.",
    "Your data directory is invalid." : "Каталог данных задан неверно.",
    "Ensure there is a file called \"%1$s\" in the root of the data directory. It should have the content: \"%2$s\"" : "Убедитесь, что в корневом каталоге данных есть файл с именем \"%1$s\". Он должен содержать следующее содержимое: \"%2$s\"",
    "Action \"%s\" not supported or implemented." : "Действие «%s» не поддерживается или не реализовано.",
    "Authentication failed, wrong token or provider ID given" : "Ошибка аутентификации, неверный токен или идентификатор провайдера",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Отсутствуют параметры для завершения запроса. Отсутствующие параметры: \"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "Идентификатор «%1$s» уже поставщиком услуг межсерверного обмена «%2$s»",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Провайдер облачной федерации с идентификатором: \"%s\" не существует.",
    "Could not obtain lock type %d on \"%s\"." : "Не удалось получить блокировку типа %d для «%s»",
    "Storage unauthorized. %s" : "Хранилище неавторизовано. %s",
    "Storage incomplete configuration. %s" : "Неполная конфигурация хранилища.  %s",
    "Storage connection error. %s" : "Ошибка подключения к хранилищу. %s",
    "Storage is temporarily not available" : "Хранилище временно недоступно",
    "Storage connection timeout. %s" : "Истекло время ожидания подключения к хранилищу. %s",
    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Чтобы разрешить эту проверку, вам нужно убедиться, что ваш веб-сервер может подключаться к себе. Поэтому он должен иметь возможность разрешать и подключаться по крайней мере к одному из своих `trusted_domains` или `overwrite.cli.url`. Эта ошибка может быть результатом несоответствия DNS на стороне сервера или исходящего правила брандмауэра.",
    "Analyze images" : "Проанализировать изображения",
    "Ask a question about the given images." : "Задать вопрос по предоставленным изображениям.",
    "Images" : "Изображения",
    "Images to ask a question about" : "Изображения для вопроса",
    "Question" : "Вопрос",
    "What to ask about the images." : "Что спросить об изображениях.",
    "Generated response" : "Сгенерированный ответ",
    "The answer to the question" : "Ответ на вопрос",
    "Audio chat" : "Аудиочат",
    "Voice chat with the assistant" : "Голосовой чат с помощником",
    "System prompt" : "Системная подсказка",
    "Define rules and assumptions that the assistant should follow during the conversation." : "Определите правила и допущения, которым ассистент должен следовать во время разговора.",
    "Chat voice message" : "Голосовое сообщение в чате",
    "Describe a task that you want the assistant to do or ask a question." : "Опишите задачу, которую вы хотите поручить помощнику, или задайте вопрос.",
    "Chat history" : "История чата",
    "The history of chat messages before the current message, starting with a message by the user." : "История сообщений в чате перед текущим сообщением, начиная с сообщения пользователя.",
    "Input transcript" : "Текстовая расшифровка ввода",
    "Transcription of the audio input" : "Текстовая расшифровка голосового ввода",
    "Response voice message" : "Голосовой ответ",
    "The generated voice response as part of the conversation" : "Сгенерированный голосовой ответ как часть беседы",
    "Output transcript" : "Текстовая расшифровка вывода",
    "Transcription of the audio output" : "Текстовая расшифровка голосового вывода",
    "Transcribe audio" : "Транскрибировать аудио",
    "Transcribe the things said in an audio" : "Запишите то, что было сказано в аудиозаписи",
    "Audio input" : "Аудиовход",
    "The audio to transcribe" : "Аудио для расшифровки",
    "Transcription" : "Транскрипция",
    "The transcribed text" : "Расшифрованный текст",
    "Chat by voice with an agent" : "Общение голосом с агентом",
    "Describe a task that you want the agent to do or ask a question." : "Опишите задачу, которую вы хотите поручить агенту, или задайте вопрос.",
    "Confirmation" : "Подтверждение",
    "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Подтвердить ранее запрошенные действия: 0 — отказ, 1 — подтверждение.",
    "Conversation token" : "Токен беседы",
    "A token representing the conversation." : "Токен, представляющий беседу.",
    "The new conversation token" : "Новый токен беседы",
    "Send this along with the next interaction." : "Отправьте его при следующем взаимодействии.",
    "Requested actions by the agent" : "Запрошенные действия от агента",
    "Actions that the agent would like to carry out in JSON format." : "Действия, которые агент хотел бы выполнить в формате JSON.",
    "Chat with an agent" : "Чат с агентом",
    "Chat message" : "Сообщение в чате",
    "A chat message to send to the agent." : "Сообщение для отправки агенту",
    "The response from the chat model." : "Ответ от модели чата.",
    "Context write" : "Контекстная запись",
    "Writes text in a given style based on the provided source material." : "Пишет текст в заданном стиле на основе предоставленного исходного материала.",
    "Writing style" : "Стиль письма",
    "Demonstrate a writing style that you would like to immitate" : "Продемонстрируйте стиль письма, которому вы хотели бы подражать",
    "Source material" : "Исходный материал",
    "The content that would like to be rewritten in the new writing style" : "Содержание, которое хотелось бы переписать в новом стиле написания",
    "Generated text" : "Сгенерированный текст",
    "The generated text with content from the source material in the given style" : "Сгенерированный текст с содержимым из исходного материала в заданном стиле",
    "Emoji generator" : "Генератор Emoji",
    "Takes text and generates a representative emoji for it." : "Берет текст и генерирует для него репрезентативный смайлик.",
    "The text to generate an emoji for" : "Текст для создания эмодзи",
    "Generated emoji" : "Созданный эмодзи",
    "The generated emoji based on the input text" : "Эмодзи, созданный на основе введённого текста",
    "Generate image" : "Генерировать изображение",
    "Generate an image from a text prompt" : "Создайте изображение из текстовой подсказки",
    "Prompt" : "Подсказка",
    "Describe the image you want to generate" : "Опишите изображение, которое вы хотите создать",
    "Number of images" : "Количество изображений",
    "How many images to generate" : "Сколько изображений генерировать",
    "Output images" : "Выходные изображения",
    "The generated images" : "Сгенерированные изображения",
    "Generate speech" : "Сгенерировать речь",
    "Generate speech from a transcript" : "Сгенерировать речь из транскрипта",
    "Write transcript that you want the assistant to generate speech from" : "Введите транскрипт, по которому ассистент должен сгенерировать речь",
    "Output speech" : "Выходное аудио",
    "The generated speech" : "Сгенерированная речь",
    "Free text to text prompt" : "Произвольное преобразование текста в текстовую подсказку",
    "Runs an arbitrary prompt through a language model that returns a reply" : "Запускает произвольный запрос с помощью языковой модели, которая возвращает ответ",
    "Describe a task that you want the assistant to do or ask a question" : "Опишите задачу, которую вы хотите поручить ассистенту, или задайте вопрос",
    "Generated reply" : "Сгенерированный ответ",
    "The generated text from the assistant" : "Сгенерированный текст от помощника",
    "Change Tone" : "Сменить тон",
    "Change the tone of a piece of text." : "Изменить тон текста",
    "Write a text that you want the assistant to rewrite in another tone." : "Напишите текст, чтобы ассистент переписал его в другом тоне.",
    "Desired tone" : "Желаемый тон",
    "In which tone should your text be rewritten?" : "В каком тоне следует переписать ваш текст?",
    "The rewritten text in the desired tone, written by the assistant:" : "Переписанный текст в нужном тоне, написанный ассистентом:",
    "Chat" : "Разговор",
    "Chat with the assistant" : "Пообщайтесь с ассистентом",
    "The history of chat messages before the current message, starting with a message by the user" : "История сообщений в чате до текущего сообщения, начиная с сообщения пользователя",
    "Response message" : "Ответное сообщение",
    "The generated response as part of the conversation" : "Сгенерированный ответ в ходе беседы",
    "Chat with tools" : "Чат с инструментами",
    "Chat with the language model with tool calling support." : "Чат с языковой моделью с поддержкой вызова инструментов.",
    "Tool message" : "Сообщение инструмента",
    "The result of tool calls in the last interaction" : "Результат вызова инструментов в последнем взаимодействии",
    "Available tools" : "Доступные инструменты",
    "The available tools in JSON format" : "Доступные инструменты в формате JSON",
    "The response from the chat model" : "Ответ от чат-модели",
    "Tool calls" : "Вызовы инструментов",
    "Tools call instructions from the model in JSON format" : "Инструкции по вызову инструментов от модели в формате JSON",
    "Formalize text" : "Формализовать текст",
    "Takes a text and makes it sound more formal" : "Берется текст и делает его звучание более формальным",
    "Write a text that you want the assistant to formalize" : "Напишите текст, который вы хотите, чтобы ассистент оформил официально",
    "Formalized text" : "Формализованный текст",
    "The formalized text" : "Формализованный текст",
    "Generate a headline" : "Создайте заголовок",
    "Generates a possible headline for a text." : "Генерирует возможный заголовок для текста.",
    "Original text" : "Оригинальный текст",
    "The original text to generate a headline for" : "Исходный текст для создания заголовка для",
    "The generated headline" : "Сгенерированный заголовок",
    "Proofread" : "Проверка правописания",
    "Proofreads a text and lists corrections" : "Проверяет текст и показывает исправления",
    "Text" : "Текст",
    "The text to proofread" : "Текст для проверки",
    "Corrections" : "Исправления",
    "The corrections that should be made in your text" : "Исправления, которые следует внести в ваш текст",
    "Reformulate text" : "Переформулировать текст",
    "Takes a text and reformulates it" : "Берет текст и переформулирует его",
    "Write a text that you want the assistant to reformulate" : "Напишите текст, который вы хотите, чтобы ассистент переформулировал",
    "Reformulated text" : "Измененный текст",
    "The reformulated text, written by the assistant" : "Переформулированный текст, написанный ассистентом",
    "Simplify text" : "Упрощение текста",
    "Takes a text and simplifies it" : "Берет текст и упрощает его",
    "Write a text that you want the assistant to simplify" : "Напишите текст, который вы хотите, чтобы ассистент упростил",
    "Simplified text" : "Упрощенный текст",
    "The simplified text" : "Упрощенный текст",
    "Summarize" : "Обобщить",
    "Summarizes a text" : "Обобщенный текст",
    "The original text to summarize" : "Исходный текст для подведения итогов",
    "Summary" : "Всего",
    "The generated summary" : "Сгенерированная сводка",
    "Extract topics" : "Извлечь темы",
    "Extracts topics from a text and outputs them separated by commas" : "Извлекает темы из текста и выводит их через запятую",
    "The original text to extract topics from" : "Исходный текст для извлечения тем из",
    "Topics" : "Темы",
    "The list of extracted topics" : "Список извлеченных тем",
    "Translate" : "Перевести",
    "Translate text from one language to another" : "Перевод текста с одного языка на другой",
    "Origin text" : "Исходный текст",
    "The text to translate" : "Текст для перевода",
    "Origin language" : "Исходный язык",
    "The language of the origin text" : "Язык исходного текста",
    "Target language" : "Целевой язык",
    "The desired language to translate the origin text in" : "Желаемый язык для перевода исходного текста",
    "Result" : "Результат",
    "The translated text" : "Переведенный текст",
    "Free prompt" : "Свободная подсказка",
    "Runs an arbitrary prompt through the language model." : "Запускает произвольное приглашение через языковую модель.",
    "Generate headline" : "Сгенерировать заголовок",
    "Summarizes text by reducing its length without losing key information." : "Обобщает текст, сокращая его длину без потери ключевой информации.",
    "Extracts topics from a text and outputs them separated by commas." : "Извлекает темы из текста и выводит их через запятую.",
    "Organisation" : "Организация",
    "File is currently busy, please try again later" : "Файл в данный момент используется, повторите попытку позже.",
    "Cannot download file" : "Не удалось скачать файл",
    "Cannot write into \"apps\" directory." : "Не удалось выполнить запись в каталог «apps».",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Обычно это можно исправить, предоставлением веб-серверу права для записи в каталог приложений или отключением магазина приложений в файле конфигурации.",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "Параметр <code>mbstring.func_overload</code> установлен в <code>%s</code>, но ожидается значение <code>0</code>.",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Чтобы исправить эту проблему установите параметр <code>mbstring.func_overload</code> в значение <code>0</code> в php.ini.",
    "Login is too long" : "Имя пользователя слишком длинное"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
